# NOT RUN {
# Subset of Immigration Choice Conjoint Experiment Data from Hainmueller et. al. (2014).
data("immigrationdata")
form = formula("Y ~ FeatEd + FeatGender + FeatCountry + FeatReason + FeatJob +
FeatExp + FeatPlans + FeatTrips + FeatLang + ppage + ppeducat + ppethm + ppgender")
left = colnames(immigrationdata)[1:9]
right = colnames(immigrationdata)[10:18]
# Testing if profile order effect is present or not in immigration data
# }
# NOT RUN {
profileorder_test = CRT_profileordereffect(formula = form, data = immigrationdata,
left = left, right = right, B = 50)
profileorder_test$p_val
# }
Run the code above in your browser using DataLab